OC.L10N.register(
    "groupfolders",
    {
    "Unset" : "Да не се задава",
    "Denied (Inherited permission)" : "Отказан (наследено право)",
    "Allowed (Inherited permission)" : "Позволен (наследено право)",
    "Denied" : "Отказан",
    "Allowed" : "Позволен",
    "Access denied" : "Отказан достъп",
    "Access allowed" : "Позволен достъп",
    "Inherit permission" : "Наследено право",
    "Deny" : "Не",
    "Allow" : "Да",
    "Group" : "Група",
    "Team" : "Екип",
    "Read" : "Четене",
    "Write" : "Писане",
    "Create" : "Създай",
    "Delete" : "Изтриване",
    "Share" : "Сподели",
    "You" : "Ти",
    "Remove access rule" : "Премахване на правилото за достъп",
    "Add advanced permission rule" : "Добавяне на разширено правило за право",
    "Select a user or group" : "Избор на потребител или група",
    "Add group" : "Нова група",
    "Default" : "По подразбиране",
    "Unlimited" : "Неограничено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Сигурни ли сте, че искате да изтриете „{folderName}“ и всички файлове вътре? Тази операция не може да бъде отменена",
    "Delete \"{folderName}\"?" : "Изтриване на \"{folderName}\"?",
    "Folder name" : "Име на папка",
    "Quota" : "Квота",
    "Advanced Permissions" : "Разширени права",
    "Previous" : "Предишно",
    "Next" : "Следващо",
    "User" : "Потребител",
    "Unknown" : "Неизвестен",
    "None" : "Няма",
    "{size} used" : "{size} използвани"
},
"nplurals=2; plural=(n != 1);");
